@@ -18,7 +18,7 @@
 #define __M4RI_HAVE_LIBPNG              1
 
 #define __M4RI_CC                       "gcc"
-#define __M4RI_CFLAGS                   "-fopenmp -march=x86-64-v4 -O3 -pipe -fno-plt -fexceptions -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security -fstack-clash-protection -fcf-protection -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -mpclmul -g -ffile-prefix-map=/startdir/src=/usr/src/debug/m4ri -flto=auto -falign-functions=32"
+#define __M4RI_CFLAGS                   "-fopenmp -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/m4ri/src=/usr/src/debug/m4ri -flto=auto"
 #define __M4RI_OPENMP_CFLAGS            "-fopenmp"
 
 // Helper macros.
